abacusai.model_metrics — AbacusAI documentation

# abacusai.model_metrics

## Classes

`AbstractApiClass` |
`ModelMetrics` | Metrics of the trained model.

## Module Contents

class abacusai.model_metrics.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.model_metrics.ModelMetrics(client, algoMetrics=None, selectedAlgorithm=None, selectedAlgorithmName=None, modelId=None, modelVersion=None, metricNames=None, targetColumn=None, trainValTestSplit=None, trainingCompletedAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Metrics of the trained model.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - algoMetrics (dict) – Dictionary mapping algorithm ID to algorithm name and algorithm metrics dictionary

    - selectedAlgorithm (str) – The algorithm ID of the selected (default) algorithm that will be used in deployments of this Model Version

    - selectedAlgorithmName (str) – The algorithm name of the selected (default) algorithm that will be used in deployments of this Model Version

    - modelId (str) – The Model ID

    - modelVersion (str) – The Model Version

    - metricNames (dict) – Maps shorthand names of the metrics to their verbose names

    - targetColumn (str) – The target feature that the model was trained to predict

    - trainValTestSplit (dict) – Info on train, val and test split

    - trainingCompletedAt (datetime) – Timestamp when training was completed

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict